@@ -28,13 +28,18 @@ build_time_vars = {'ABIFLAGS': '',
            '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
            '-Werror=format-security         -fstack-clash-protection '
-           '-fcf-protection -flto=auto -ffat-lto-objects -march=x86-64 '
-           '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -fcf-protection -flto=auto -march=x86-64 '
-           '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -fcf-protection -flto=auto',
+           '-fcf-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto '
+           '-ffat-lto-objects -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection '
+           '-fcf-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto '
+           '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection '
+           '-fcf-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -43,7 +48,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS': '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
                      '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                      '-Werror=format-security         -fstack-clash-protection '
-                     '-fcf-protection -flto=auto -ffat-lto-objects',
+                     '-fcf-protection -g '
+                     '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                     '-flto=auto -ffat-lto-objects',
  'CONFIGURE_CFLAGS_NODIST': '-fno-semantic-interposition -flto '
                             '-fuse-linker-plugin -ffat-lto-objects '
                             '-flto-partition=none -g -std=c99 -Wextra '
@@ -66,14 +73,16 @@ build_time_vars = {'ABIFLAGS': '',
                 '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
                 '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                 '-Werror=format-security         -fstack-clash-protection '
-                "-fcf-protection -flto=auto -ffat-lto-objects' "
+                '-fcf-protection -g '
+                '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto '
+                "-ffat-lto-objects' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
                 "-flto=auto'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.10.4/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.10.4/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.10.6/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.10.6/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
@@ -673,17 +682,20 @@ build_time_vars = {'ABIFLAGS': '',
                              '-O3 -pipe -fno-plt -fexceptions         '
                              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                              '-Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection '
+                             '-fstack-clash-protection -fcf-protection -g '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
                              '-flto=auto -ffat-lto-objects -march=x86-64 '
                              '-mtune=generic -O3 -pipe -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection '
+                             '-fstack-clash-protection -fcf-protection -g '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
                              '-flto=auto -march=x86-64 -mtune=generic -O3 '
                              '-pipe -fno-plt -fexceptions         '
                              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                              '-Werror=format-security         '
-                             '-fstack-clash-protection -fcf-protection '
+                             '-fstack-clash-protection -fcf-protection -g '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
                              '-flto=auto -fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects '
                              '-flto-partition=none -g -std=c99 -Wextra '
@@ -696,14 +708,18 @@ build_time_vars = {'ABIFLAGS': '',
               '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
-              '-fcf-protection -flto=auto -ffat-lto-objects -march=x86-64 '
-              '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-fcf-protection -g '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto '
+              '-ffat-lto-objects -march=x86-64 -mtune=generic -O3 -pipe '
+              '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
-              '-fcf-protection -flto=auto -march=x86-64 -mtune=generic -O3 '
-              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
-              '-Wformat -Werror=format-security         '
-              '-fstack-clash-protection -fcf-protection -flto=auto',
+              '-fcf-protection -g '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto '
+              '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-Werror=format-security         -fstack-clash-protection '
+              '-fcf-protection -g '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto',
  'PY_CFLAGS_NODIST': '-fno-semantic-interposition -flto -fuse-linker-plugin '
                      '-ffat-lto-objects -flto-partition=none -g -std=c99 '
                      '-Wextra -Wno-unused-result -Wno-unused-parameter '
@@ -715,19 +731,23 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Wall -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -flto=auto -ffat-lto-objects -march=x86-64 '
-                   '-mtune=generic -O3 -pipe -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                   '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -flto=auto -march=x86-64 -mtune=generic '
+                   '-fcf-protection -g '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-flto=auto -ffat-lto-objects -march=x86-64 -mtune=generic '
                    '-O3 -pipe -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-fcf-protection -flto=auto -fno-semantic-interposition '
-                   '-flto -fuse-linker-plugin -ffat-lto-objects '
-                   '-flto-partition=none -g -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
+                   '-fcf-protection -g '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-fcf-protection -g '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-flto=auto -fno-semantic-interposition -flto '
+                   '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
+                   '-g -std=c99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
@@ -749,19 +769,23 @@ build_time_vars = {'ABIFLAGS': '',
                         '-O3 -Wall -march=x86-64 -mtune=generic -O3 -pipe '
                         '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wformat -Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -flto=auto '
-                        '-ffat-lto-objects -march=x86-64 -mtune=generic -O3 '
-                        '-pipe -fno-plt -fexceptions         '
-                        '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                        '-Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -flto=auto '
-                        '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+                        '-fstack-clash-protection -fcf-protection -g '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-flto=auto -ffat-lto-objects -march=x86-64 '
+                        '-mtune=generic -O3 -pipe -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -fcf-protection -flto=auto '
-                        '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                        '-ffat-lto-objects -flto-partition=none -g -std=c99 '
-                        '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                        '-fstack-clash-protection -fcf-protection -g '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe '
+                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-Wformat -Werror=format-security         '
+                        '-fstack-clash-protection -fcf-protection -g '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-flto=auto -fno-semantic-interposition -flto '
+                        '-fuse-linker-plugin -ffat-lto-objects '
+                        '-flto-partition=none -g -std=c99 -Wextra '
+                        '-Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
@@ -774,7 +798,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.4',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.6',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -816,9 +840,9 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.4 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.6 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.4 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.6 ./python '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -846,8 +870,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.10.4',
- 'abs_srcdir': '/build/python/src/Python-3.10.4',
+ 'abs_builddir': '/build/python/src/Python-3.10.6',
+ 'abs_srcdir': '/build/python/src/Python-3.10.6',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
